@@ -2,6 +2,8 @@
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
  *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2018, Raul Rodrigo Segura (raurodse)
+ *   Copyright 2019, Collabora Ltd <arnaud.ferraris@collabora.com>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -34,6 +36,8 @@
 #include <QDesktopWidget>
 #include <QLabel>
 #include <QTreeView>
+#include <QFile>
+#include <QFileInfo>
 
 static inline int
 windowDimensionToPixels( const Calamares::Branding::WindowDimension& u )
@@ -53,8 +57,10 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
     , m_viewManager( nullptr )
 {
     CALAMARES_RETRANSLATE(
-        setWindowTitle( tr( "%1 Installer" )
-                        .arg( *Calamares::Branding::ProductName ) );
+        setWindowTitle( Calamares::Settings::instance()->isSetupMode()
+                            ? tr( "%1 Setup Program" ).arg( *Calamares::Branding::ProductName )
+                            : tr( "%1 Installer" ).arg( *Calamares::Branding::ProductName )
+                         );
     )
 
     const Calamares::Branding* const branding = Calamares::Branding::instance();
@@ -64,6 +70,8 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
     using CalamaresUtils::windowPreferredHeight;
     using CalamaresUtils::windowPreferredWidth;
 
+    this->setObjectName("mainApp");
+
     QSize availableSize = qApp->desktop()->availableGeometry( this ).size();
     QSize minimumSize( qBound( windowMinimumWidth, availableSize.width(), windowPreferredWidth ),
                        qBound( windowMinimumHeight, availableSize.height(), windowPreferredHeight ) );
@@ -76,17 +84,19 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
     int w = qBound( minimumSize.width(), windowDimensionToPixels( brandingSizes.first ), availableSize.width() );
     int h = qBound( minimumSize.height(),  windowDimensionToPixels( brandingSizes.second ), availableSize.height() );
 
-    cDebug() << "  Proposed window size:" << w << h;
+    cDebug() << Logger::SubEntry << "Proposed window size:" << w << h;
     resize( w, h );
 
     QBoxLayout* mainLayout = new QHBoxLayout;
     setLayout( mainLayout );
 
     QWidget* sideBox = new QWidget( this );
+    sideBox->setObjectName("sidebarApp");
     mainLayout->addWidget( sideBox );
 
     QBoxLayout* sideLayout = new QVBoxLayout;
     sideBox->setLayout( sideLayout );
+    // Set this attribute into qss file
     sideBox->setFixedWidth( qBound( 100, CalamaresUtils::defaultFontHeight() * 12, w < windowPreferredWidth ? 100 : 190 ) );
     sideBox->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );
 
@@ -94,6 +104,8 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
     sideLayout->addLayout( logoLayout );
     logoLayout->addStretch();
     QLabel* logoLabel = new QLabel( sideBox );
+    logoLabel->setObjectName("logoApp");
+    //Define all values into qss file
     {
         QPalette plt = sideBox->palette();
         sideBox->setAutoFillBackground( true );
@@ -151,6 +163,7 @@ CalamaresWindow::CalamaresWindow( QWidget* parent )
         connect( m_viewManager, &Calamares::ViewManager::enlarge, this, &CalamaresWindow::enlarge );
 
     mainLayout->addWidget( m_viewManager->centralWidget() );
+    setStyleSheet( Calamares::Branding::instance()->stylesheet() );
 }
 
 void
