@@ -2,6 +2,7 @@
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
  *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2018, Raul Rodrigo Segura (raurodse)
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -32,9 +33,6 @@
 #include <QPixmap>
 #include <QVariantMap>
 
-#include <yaml-cpp/yaml.h>
-
-
 namespace Calamares
 {
 
@@ -78,8 +76,8 @@ const QStringList Branding::s_styleEntryStrings =
     "sidebarTextHighlight"
 };
 
-static const NamedEnumTable<Branding::WindowDimensionUnit>&
-windowDimensions()
+const NamedEnumTable<Branding::WindowDimensionUnit>&
+Branding::WindowDimension::suffixes()
 {
     using Unit = Branding::WindowDimensionUnit;
     static const NamedEnumTable<Unit> names{
@@ -94,7 +92,6 @@ Branding::Branding( const QString& brandingFilePath,
                     QObject* parent )
     : QObject( parent )
     , m_descriptorPath( brandingFilePath )
-    , m_componentName()
     , m_welcomeStyleCalamares( false )
     , m_welcomeExpandingLogo( true )
 {
@@ -201,6 +198,16 @@ Branding::Branding( const QString& brandingFilePath,
         m_translationsPathPrefix.append( QString( "%1calamares-%2" )
                                             .arg( QDir::separator() )
                                             .arg( m_componentName ) );
+
+        QFileInfo importQSSPath( componentDir.filePath( "stylesheet.qss" ) );
+        if ( importQSSPath.exists() && importQSSPath.isReadable() )
+        {
+            QFile stylesheetFile( importQSSPath.filePath() );
+            stylesheetFile.open( QFile::ReadOnly );
+            m_stylesheet = stylesheetFile.readAll();
+        }
+        else
+            cWarning() << "the branding component" << componentDir.absolutePath() << "does not ship stylesheet.qss.";
     }
     else
     {
@@ -219,20 +226,6 @@ Branding::Branding( const QString& brandingFilePath,
 }
 
 
-QString
-Branding::descriptorPath() const
-{
-    return m_descriptorPath;
-}
-
-
-QString
-Branding::componentName() const
-{
-    return m_componentName;
-}
-
-
 QString
 Branding::componentDirectory() const
 {
@@ -241,13 +234,6 @@ Branding::componentDirectory() const
 }
 
 
-QString
-Branding::translationsPathPrefix() const
-{
-    return m_translationsPathPrefix;
-}
-
-
 QString
 Branding::string( Branding::StringEntry stringEntry ) const
 {
@@ -284,12 +270,6 @@ Branding::image( Branding::ImageEntry imageEntry, const QSize& size ) const
 }
 
 
-QString
-Branding::slideshowPath() const
-{
-    return m_slideshowPath;
-}
-
 void
 Branding::setGlobals( GlobalStorage* globalStorage ) const
 {
@@ -323,11 +303,6 @@ Branding::initSimpleSettings( const YAML::Node& doc )
         { QStringLiteral( "fullscreen" ), WindowExpansion::Fullscreen },
         { QStringLiteral( "noexpand" ), WindowExpansion::Fixed }
     };
-    static const NamedEnumTable< WindowDimensionUnit > dimensionNames{
-        { QStringLiteral( "px" ), WindowDimensionUnit::Pixies },
-        { QStringLiteral( "em" ), WindowDimensionUnit::Fonties }
-    };
-
     bool ok = false;
 
     m_welcomeStyleCalamares = doc[ "welcomeStyleCalamares" ].as< bool >( false );
@@ -342,8 +317,8 @@ Branding::initSimpleSettings( const YAML::Node& doc )
         auto l = windowSize.split( ',' );
         if ( l.count() == 2 )
         {
-            m_windowWidth = WindowDimension( dimensionNames, l[0] );
-            m_windowHeight = WindowDimension( dimensionNames, l[1] );
+            m_windowWidth = WindowDimension( l[0] );
+            m_windowHeight = WindowDimension( l[1] );
         }
     }
     if ( !m_windowWidth.isValid() )
@@ -353,7 +328,7 @@ Branding::initSimpleSettings( const YAML::Node& doc )
 }
 
 
-void
+[[noreturn]] void
 Branding::bail( const QString& message )
 {
     cError() << "FATAL in"
