@@ -1,5 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
+ *   Copyright 2019, Dominic Hayes <ferenosdev@outlook.com>
+ *   Copyright 2019, Gabriel Craciunescu <crazy@frugalware.org>
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
  *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
  *
@@ -74,7 +76,10 @@ ViewManager::ViewManager( QObject* parent )
         m_back->setText( tr( "&Back" ) );
         m_next->setText( tr( "&Next" ) );
         m_quit->setText( tr( "&Cancel" ) );
-        m_quit->setToolTip( tr( "Cancel installation without changing the system." ) );
+        QString tooltip = Calamares::Settings::instance()->isSetupMode()
+            ? tr( "Cancel setup without changing the system." )
+            : tr( "Cancel installation without changing the system." );
+        m_quit->setToolTip( tooltip );
     )
 
     QBoxLayout* bottomLayout = new QHBoxLayout;
@@ -95,6 +100,9 @@ ViewManager::ViewManager( QObject* parent )
              this, &ViewManager::onInstallationFailed );
     connect( JobQueue::instance(), &JobQueue::finished,
              this, &ViewManager::next );
+
+    if (Calamares::Settings::instance()->disableCancel())
+        m_quit->setVisible( false );
 }
 
 
@@ -155,10 +163,13 @@ ViewManager::onInstallationFailed( const QString& message, const QString& detail
     cDebug() << "- message:" << message;
     cDebug() << "- details:" << details;
 
+    QString heading = Calamares::Settings::instance()->isSetupMode()
+        ? tr( "Setup Failed" )
+        : tr( "Installation Failed" );
     QMessageBox* msgBox = new QMessageBox();
     msgBox->setIcon( QMessageBox::Critical );
     msgBox->setWindowTitle( tr( "Error" ) );
-    msgBox->setText( "<strong>" + tr( "Installation Failed" ) + "</strong>" );
+    msgBox->setText( "<strong>" + heading + "</strong>" );
     msgBox->setStandardButtons( QMessageBox::Close );
     msgBox->button( QMessageBox::Close )->setText( tr( "&Close" ) );
 
@@ -176,6 +187,8 @@ ViewManager::onInstallationFailed( const QString& message, const QString& detail
 void
 ViewManager::onInitFailed( const QStringList& modules)
 {
+    // Because this means the installer / setup program is broken by the distributor,
+    // don't bother being precise about installer / setup wording.
     QString title( tr( "Calamares Initialization Failed" ) );
     QString description( tr( "%1 can not be installed. Calamares was unable to load all of the configured modules. This is a problem with the way Calamares is being used by the distribution." ) );
     QString detailString;
@@ -191,7 +204,7 @@ ViewManager::onInitFailed( const QStringList& modules)
         detailString = details.join( QString() );
     }
 
-    insertViewStep( 0, new BlankViewStep( title, description.arg( *Calamares::Branding::ShortProductName ), detailString ) );
+    insertViewStep( 0, new BlankViewStep( title, description.arg( *Calamares::Branding::ProductName ), detailString ) );
 }
 
 ViewStepList
@@ -227,20 +240,32 @@ ViewManager::next()
     bool executing = false;
     if ( step->isAtEnd() )
     {
+        const auto* const settings = Calamares::Settings::instance();
+        
         // Special case when the user clicks next on the very last page in a view phase
         // and right before switching to an execution phase.
         // Depending on Calamares::Settings, we show an "are you sure" prompt or not.
-        if ( Calamares::Settings::instance()->showPromptBeforeExecution() && stepNextWillExecute( m_steps, m_currentStep ) )
+        if ( settings->showPromptBeforeExecution() && stepNextWillExecute( m_steps, m_currentStep ) )
         {
+            QString title = settings->isSetupMode()
+                ? tr( "Continue with setup?" )
+                : tr( "Continue with installation?" );
+            QString question = settings->isSetupMode()
+                ? tr( "The %1 setup program is about to make changes to your "
+                      "disk in order to set up %2.<br/><strong>You will not be able "
+                      "to undo these changes.</strong>" )
+                : tr( "The %1 installer is about to make changes to your "
+                      "disk in order to install %2.<br/><strong>You will not be able "
+                      "to undo these changes.</strong>" );
+            QString confirm = settings->isSetupMode()
+                ? tr( "&Set up now" )
+                : tr( "&Install now" );
+
             int reply =
                 QMessageBox::question( m_widget,
-                                       tr( "Continue with setup?" ),
-                                       tr( "The %1 installer is about to make changes to your "
-                                           "disk in order to install %2.<br/><strong>You will not be able "
-                                           "to undo these changes.</strong>" )
-                                       .arg( *Calamares::Branding::ShortProductName )
-                                       .arg( *Calamares::Branding::ShortVersionedName ),
-                                       tr( "&Install now" ),
+                                       title,
+                                       question.arg( *Calamares::Branding::ShortProductName, *Calamares::Branding::ShortVersionedName ),
+                                       confirm,
                                        tr( "Go &back" ),
                                        QString(),
                                        0,
@@ -259,7 +284,12 @@ ViewManager::next()
         {
             m_back->setEnabled( false );
             m_next->setEnabled( false );
+            // Enabled if there's nothing blocking it during exec
+            m_quit->setEnabled( !( settings->dontCancel() || settings->disableCancel() ) );
         }
+        else
+            // Enabled unless it's also hidden
+            m_quit->setEnabled( !settings->disableCancel() );
     }
     else
         step->next();
@@ -273,20 +303,37 @@ ViewManager::next()
 void
 ViewManager::updateButtonLabels()
 {
+    QString next = Calamares::Settings::instance()->isSetupMode()
+        ? tr( "&Set up" )
+        : tr( "&Install" );
+    QString complete = Calamares::Settings::instance()->isSetupMode()
+        ? tr( "Setup is complete. Close the setup program." )
+        : tr( "The installation is complete. Close the installer." );
+    QString quit = Calamares::Settings::instance()->isSetupMode()
+        ? tr( "Cancel setup without changing the system." )
+        : tr( "Cancel installation without changing the system." );
+
     if ( stepNextWillExecute( m_steps, m_currentStep ) )
-        m_next->setText( tr( "&Install" ) );
+        m_next->setText( next );
     else
         m_next->setText( tr( "&Next" ) );
 
     if ( m_currentStep == m_steps.count() -1 && m_steps.last()->isAtEnd() )
     {
         m_quit->setText( tr( "&Done" ) );
-        m_quit->setToolTip( tr( "The installation is complete. Close the installer." ) );
+        m_quit->setToolTip( complete );
+        m_quit->setVisible( true );  // At end, always visible and enabled.
+        m_quit->setEnabled( true );
     }
     else
     {
+        if ( Calamares::Settings::instance()->disableCancel() )
+        {
+            m_quit->setVisible( false );
+            m_quit->setEnabled( false );  // Can't be triggered through DBUS
+        }
         m_quit->setText( tr( "&Cancel" ) );
-        m_quit->setToolTip( tr( "Cancel installation without changing the system." ) );
+        m_quit->setToolTip( quit );
     }
 }
 
@@ -321,10 +368,17 @@ bool ViewManager::confirmCancelInstallation()
     if ( !( m_currentStep == m_steps.count() -1 &&
             m_steps.last()->isAtEnd() ) )
     {
+        QString title = Calamares::Settings::instance()->isSetupMode()
+            ? tr( "Cancel setup?" )
+            : tr( "Cancel installation?" );
+        QString question = Calamares::Settings::instance()->isSetupMode()
+            ? tr( "Do you really want to cancel the current setup process?\n"
+                  "The setup program will quit and all changes will be lost." )
+            : tr( "Do you really want to cancel the current install process?\n"
+                  "The installer will quit and all changes will be lost." );
         QMessageBox mb( QMessageBox::Question,
-                        tr( "Cancel installation?" ),
-                        tr( "Do you really want to cancel the current install process?\n"
-                            "The installer will quit and all changes will be lost." ),
+                        title,
+                        question,
                         QMessageBox::Yes | QMessageBox::No,
                         m_widget );
         mb.setDefaultButton( QMessageBox::No );
