@@ -36,8 +36,6 @@
 #include "PythonQtViewModule.h"
 #endif
 
-#include <yaml-cpp/yaml.h>
-
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
@@ -145,8 +143,19 @@ moduleConfigurationCandidates( bool assumeBuildDir, const QString& moduleName, c
         paths << CalamaresUtils::appDataDir().absoluteFilePath( QString( "modules/%1" ).arg( configFileName ) );
     else
     {
+        // If an absolute path is given, in debug mode, look for it
+        // first. The case contains('/'), below, will add the absolute
+        // path a second time, though.
+        if ( assumeBuildDir && configFileName.startsWith( '/' ) )
+            paths << configFileName;
         if ( assumeBuildDir )
             paths << QDir().absoluteFilePath(QString( "src/modules/%1/%2" ).arg( moduleName ).arg( configFileName ) );
+        if ( assumeBuildDir && configFileName.contains( '/' ) )
+            paths << QDir().absoluteFilePath( configFileName );
+
+        if ( CalamaresUtils::haveExtraDirs() )
+            for ( auto s : CalamaresUtils::extraConfigDirs() )
+                paths << ( s + QString( "modules/%1" ).arg( configFileName ) );
 
         paths << QString( "/etc/calamares/modules/%1" ).arg( configFileName );
         paths << CalamaresUtils::appDataDir().absoluteFilePath( QString( "modules/%1" ).arg( configFileName ) );
@@ -158,7 +167,8 @@ moduleConfigurationCandidates( bool assumeBuildDir, const QString& moduleName, c
 void
 Module::loadConfigurationFile( const QString& configFileName ) //throws YAML::Exception
 {
-    foreach ( const QString& path, moduleConfigurationCandidates( Settings::instance()->debugMode(), m_name, configFileName ) )
+    QStringList configCandidates = moduleConfigurationCandidates( Settings::instance()->debugMode(), m_name, configFileName );
+    for ( const QString& path : configCandidates )
     {
         QFile configFile( path );
         if ( configFile.exists() && configFile.open( QFile::ReadOnly | QFile::Text ) )
@@ -168,6 +178,7 @@ Module::loadConfigurationFile( const QString& configFileName ) //throws YAML::Ex
             YAML::Node doc = YAML::Load( ba.constData() );
             if ( doc.IsNull() )
             {
+                cDebug() << "Found empty module configuration" << path;
                 // Special case: empty config files are valid,
                 // but aren't a map.
                 return;
@@ -178,15 +189,15 @@ Module::loadConfigurationFile( const QString& configFileName ) //throws YAML::Ex
                 return;
             }
 
+            cDebug() << "Loaded module configuration" << path;
             m_configurationMap = CalamaresUtils::yamlMapToVariant( doc ).toMap();
             m_emergency = m_maybe_emergency
                           && m_configurationMap.contains( EMERGENCY )
                           && m_configurationMap[ EMERGENCY ].toBool();
             return;
         }
-        else
-            continue;
     }
+    cDebug() << "No config file found in" << Logger::DebugList( configCandidates );
 }
 
 
@@ -270,4 +281,10 @@ Module::initFrom( const QVariantMap& moduleDescriptor )
         m_maybe_emergency = moduleDescriptor[ EMERGENCY ].toBool();
 }
 
+RequirementsList
+Module::checkRequirements()
+{
+    return RequirementsList();
+}
+
 } //ns
