@@ -23,6 +23,7 @@
 #include "utils/CalamaresUtils.h"
 #include "UiDllMacro.h"
 
+#include <QObject>
 #include <QPixmap>
 #include <QSize>
 
@@ -125,6 +126,7 @@ constexpr int windowMinimumWidth = 800;
 constexpr int windowMinimumHeight = 520;
 constexpr int windowPreferredWidth = 1024;
 constexpr int windowPreferredHeight = 520;
-}
+
+}  // namespace CalamaresUtils
 
 #endif // CALAMARESUTILSGUI_H
