@@ -21,9 +21,12 @@
 #define VIEWSTEP_H
 
 #include <QObject>
+#include <QSize>
 
-#include "../UiDllMacro.h"
 #include "Typedefs.h"
+#include "UiDllMacro.h"
+
+#include "modulesystem/Requirement.h"
 
 namespace Calamares
 {
@@ -68,13 +71,39 @@ public:
     //TODO: we might want to make this a QSharedPointer
     virtual QWidget* widget() = 0;
 
-    virtual void next() = 0;
-    virtual void back() = 0;
+    /**
+     * @brief Multi-page support, go next
+     *
+     * Multi-page view steps need to manage the content visible in the widget
+     * themselves. This method is called when the user clicks the *next*
+     * button, and should switch to the next of the multiple-pages. It needs
+     * to be consistent with both isNextEnabled() and isAtEnd().
+     *
+     * In particular: when isAtEnd() returns false, next() is called when
+     * the user clicks the button and a new page should be shown by this
+     * view step. When isAtEnd() returns true, clicking the button will
+     * switch to the next view step in sequence, rather than a next page
+     * in the current view step.
+     */
+    virtual void next();
+    /// @brief Multi-page support, go back
+    virtual void back();
 
+    /// @brief Can the user click *next* with currently-filled-in data?
     virtual bool isNextEnabled() const = 0;
+    /// @brief Can the user click *previous* with currently-filled-in data?
     virtual bool isBackEnabled() const = 0;
 
+    /**
+     * @brief Multi-page support, switch to previous view step?
+     *
+     * For a multi-page view step, this indicates that the first (beginning)
+     * page is showing. Clicking *previous* when at the beginning of a view
+     * step, switches to the previous step, not the previous page of the
+     * current view step.
+     */
     virtual bool isAtBeginning() const = 0;
+    /// @brief Multi-page support, switch to next view step?
     virtual bool isAtEnd() const = 0;
 
     /**
@@ -91,6 +120,12 @@ public:
      */
     virtual void onLeave();
 
+    /**
+     * @brief Jobs needed to run this viewstep
+     *
+     * When a ViewStep is listed in the exec section, its jobs are executed instead.
+     * This function returns that list of jobs; an empty list is ok.
+     */
     virtual JobList jobs() const = 0;
 
     void setModuleInstanceKey( const QString& instanceKey );
@@ -101,9 +136,18 @@ public:
 
     virtual void setConfigurationMap( const QVariantMap& configurationMap );
 
+    /**
+     * @brief Can this module proceed, on this machine?
+     *
+     * This is called asynchronously at startup, and returns a list of
+     * the requirements that the module has checked, and their status.
+     * See Calamares::RequirementEntry for details.
+     */
+    virtual RequirementsList checkRequirements();
+
 signals:
+    /// @brief Tells the viewmanager to enable the *next* button according to @p status
     void nextStatusChanged( bool status );
-    void done();
 
     /* Emitted when the viewstep thinks it needs more space than is currently
      * available for display. @p enlarge is the requested additional space,
