@@ -5,6 +5,7 @@
 #
 #   Copyright 2014, Philip Müller <philm@manjaro.org>
 #   Copyright 2017, Alf Gaida <agaida@siduction.org>
+#   Copyright 2019, Adriaan de Groot <groot@kde.org>
 #
 #   Calamares is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -19,9 +20,21 @@
 #   You should have received a copy of the GNU General Public License
 #   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
 
+import libcalamares
 from libcalamares.utils import target_env_call
 
 
+import gettext
+_ = gettext.translation("calamares-python",
+                        localedir=libcalamares.utils.gettext_path(),
+                        languages=libcalamares.utils.gettext_languages(),
+                        fallback=True).gettext
+
+
+def pretty_name():
+    return _("Creating initramfs.")
+
+
 def run():
     """ Generate an initramfs image.
 
@@ -31,7 +44,8 @@ def run():
                                    "-t"])
 
     if return_code != 0:
+        libcalamares.utils.debug("update-initramfs returned {}".format(return_code))
         return (
-            "Failed to run update-initramfs on the target",
-            "The exit code was {}".format(return_code)
+            _("Failed to run update-initramfs on the target"),
+            _("The exit code was {}").format(return_code)
             )
