@@ -19,22 +19,25 @@
 
 #include "LocalePage.h"
 
-#include "timezonewidget/timezonewidget.h"
 #include "SetTimezoneJob.h"
-#include "utils/Logger.h"
-#include "utils/Retranslator.h"
+#include "timezonewidget/timezonewidget.h"
+
 #include "GlobalStorage.h"
 #include "JobQueue.h"
 #include "LCLocaleDialog.h"
 #include "Settings.h"
 
+#include "utils/CalamaresUtilsGui.h"
+#include "utils/LocaleLabel.h"
+#include "utils/Logger.h"
+#include "utils/Retranslator.h"
+
 #include <QBoxLayout>
 #include <QComboBox>
 #include <QLabel>
 #include <QPushButton>
 #include <QProcess>
 
-
 LocalePage::LocalePage( QWidget* parent )
     : QWidget( parent )
     , m_blockTzWidgetSet( false )
@@ -100,7 +103,7 @@ LocalePage::LocalePage( QWidget* parent )
              static_cast< void ( QComboBox::* )( int ) >( &QComboBox::currentIndexChanged ),
              [this]( int currentIndex )
     {
-        Q_UNUSED( currentIndex );
+        Q_UNUSED( currentIndex )
         QHash< QString, QList< LocaleGlobal::Location > > regions = LocaleGlobal::getLocations();
         if ( !regions.contains( m_regionCombo->currentData().toString() ) )
             return;
@@ -384,12 +387,14 @@ LocalePage::init( const QString& initialRegion,
 
 std::pair< QString, QString > LocalePage::prettyLocaleStatus( const LocaleConfiguration& lc ) const
 {
+    using CalamaresUtils::LocaleLabel;
+
+    LocaleLabel lang( lc.language(), LocaleLabel::LabelFormat::AlwaysWithCountry );
+    LocaleLabel num( lc.lc_numeric, LocaleLabel::LabelFormat::AlwaysWithCountry );
+
     return std::make_pair< QString, QString >(
-        tr( "The system language will be set to %1." )
-            .arg( prettyLCLocale( lc.language() ) ),
-        tr( "The numbers and dates locale will be set to %1." )
-                            .arg( prettyLCLocale( lc.lc_numeric ) )
-                                             );
+        tr( "The system language will be set to %1." ).arg( lang.label() ),
+        tr( "The numbers and dates locale will be set to %1." ).arg( num.label() ) );
 }
 
 QString
@@ -457,20 +462,6 @@ LocalePage::guessLocaleConfiguration() const
 }
 
 
-QString
-LocalePage::prettyLCLocale( const QString& lcLocale ) const
-{
-    QString localeString = lcLocale;
-    if ( localeString.endsWith( " UTF-8" ) )
-        localeString.remove( " UTF-8" );
-
-    QLocale locale( localeString );
-    //: Language (Country)
-    return tr( "%1 (%2)" ).arg( QLocale::languageToString( locale.language() ) )
-                          .arg( QLocale::countryToString( locale.country() ) );
-}
-
-
 void
 LocalePage::updateGlobalLocale()
 {
