@@ -7,7 +7,7 @@
 #   Copyright 2015, Philip Müller <philm@manjaro.org>
 #   Copyright 2016, Teo Mrnjavac <teo@kde.org>
 #   Copyright 2018, AlmAck <gluca86@gmail.com>
-#   Copyright 2018, Adriaan de Groot <groot@kde.org>
+#   Copyright 2018-2019, Adriaan de Groot <groot@kde.org>
 #
 #   Calamares is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -26,6 +26,19 @@ import os
 import re
 import shutil
 
+import libcalamares
+
+import gettext
+_ = gettext.translation("calamares-python",
+                        localedir=libcalamares.utils.gettext_path(),
+                        languages=libcalamares.utils.gettext_languages(),
+                        fallback=True).gettext
+
+
+def pretty_name():
+    return _("Configuring locales.")
+
+
 RE_IS_COMMENT = re.compile("^ *#")
 def is_comment(line):
     """
