@@ -1,7 +1,8 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2015-2016, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2018, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2018-2019 Adriaan de Groot <groot@kde.org>
+ *   Copyright 2019, Collabora Ltd <arnaud.ferraris@collabora.com>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -42,6 +43,235 @@
 namespace PartUtils
 {
 
+static const NamedEnumTable<SizeUnit>&
+unitSuffixes()
+{
+    static const NamedEnumTable<SizeUnit> names{
+        { QStringLiteral( "%" ), SizeUnit::Percent },
+        { QStringLiteral( "B" ), SizeUnit::Byte },
+        { QStringLiteral( "K" ), SizeUnit::KiB },
+        { QStringLiteral( "M" ), SizeUnit::MiB },
+        { QStringLiteral( "G" ), SizeUnit::GiB }
+    };
+
+    return names;
+}
+
+PartSize::PartSize( const QString& s )
+    : NamedSuffix( unitSuffixes(), s )
+{
+    if ( ( unit() == SizeUnit::Percent ) && ( value() > 100 || value() < 0 ) )
+    {
+        cDebug() << "Percent value" << value() << "is not valid.";
+        m_value = 0;
+    }
+
+    if ( m_unit == SizeUnit::None )
+    {
+        m_value = s.toInt();
+        if ( m_value > 0 )
+            m_unit = SizeUnit::Byte;
+    }
+
+    if ( m_value <= 0 )
+    {
+        m_value = 0;
+        m_unit = SizeUnit::None;
+    }
+}
+
+qint64
+PartSize::toSectors( qint64 totalSectors, qint64 sectorSize ) const
+{
+    if ( !isValid() )
+        return -1;
+    if ( totalSectors < 1 || sectorSize < 1 )
+        return -1;
+
+    switch ( m_unit )
+    {
+    case unit_t::None:
+        return -1;
+    case unit_t::Percent:
+        if ( value() == 100 )
+            return totalSectors;  // Common-case, avoid futzing around
+        else
+            return totalSectors * value() / 100;
+    case unit_t::Byte:
+    case unit_t::KiB:
+    case unit_t::MiB:
+    case unit_t::GiB:
+        return bytesToSectors ( toBytes(), sectorSize );
+    }
+
+    return -1;
+}
+
+qint64
+PartSize::toBytes( qint64 totalSectors, qint64 sectorSize ) const
+{
+    if ( !isValid() )
+        return -1;
+
+    switch ( m_unit )
+    {
+    case unit_t::None:
+        return -1;
+    case unit_t::Percent:
+        if ( totalSectors < 1 || sectorSize < 1 )
+            return -1;
+        if ( value() == 100 )
+            return totalSectors * sectorSize;  // Common-case, avoid futzing around
+        else
+            return totalSectors * value() / 100;
+    case unit_t::Byte:
+    case unit_t::KiB:
+    case unit_t::MiB:
+    case unit_t::GiB:
+        return toBytes();
+    }
+
+    // notreached
+    return -1;
+}
+
+qint64
+PartSize::toBytes( qint64 totalBytes ) const
+{
+    if ( !isValid() )
+        return -1;
+
+    switch ( m_unit )
+    {
+    case unit_t::None:
+        return -1;
+    case unit_t::Percent:
+        if ( totalBytes < 1 )
+            return -1;
+        if ( value() == 100 )
+            return totalBytes;  // Common-case, avoid futzing around
+        else
+            return totalBytes * value() / 100;
+    case unit_t::Byte:
+    case unit_t::KiB:
+    case unit_t::MiB:
+    case unit_t::GiB:
+        return toBytes();
+    }
+
+    // notreached
+    return -1;
+}
+
+qint64
+PartSize::toBytes() const
+{
+    if ( !isValid() )
+        return -1;
+
+    switch ( m_unit )
+    {
+    case unit_t::Byte:
+        return value();
+    case unit_t::KiB:
+        return CalamaresUtils::KiBtoBytes( static_cast<unsigned long long>( value() ) );
+    case unit_t::MiB:
+        return CalamaresUtils::MiBtoBytes( static_cast<unsigned long long>( value() ) );
+    case unit_t::GiB:
+        return CalamaresUtils::GiBtoBytes( static_cast<unsigned long long>( value() ) );
+    default:
+        break;
+    }
+
+    // Reached only when unit is Percent or None
+    return -1;
+}
+
+bool
+PartSize::operator< ( const PartSize& other ) const
+{
+    if ( ( m_unit == SizeUnit::None || other.m_unit == SizeUnit::None ) ||
+         ( m_unit == SizeUnit::Percent && other.m_unit != SizeUnit::Percent ) ||
+         ( m_unit != SizeUnit::Percent && other.m_unit == SizeUnit::Percent ) )
+        return false;
+
+    switch ( m_unit )
+    {
+    case SizeUnit::Percent:
+        return ( m_value < other.m_value );
+    case SizeUnit::Byte:
+    case SizeUnit::KiB:
+    case SizeUnit::MiB:
+    case SizeUnit::GiB:
+        return ( toBytes() < other.toBytes () );
+    }
+
+    return false;
+}
+
+bool
+PartSize::operator> ( const PartSize& other ) const
+{
+    if ( ( m_unit == SizeUnit::None || other.m_unit == SizeUnit::None ) ||
+         ( m_unit == SizeUnit::Percent && other.m_unit != SizeUnit::Percent ) ||
+         ( m_unit != SizeUnit::Percent && other.m_unit == SizeUnit::Percent ) )
+        return false;
+
+    switch ( m_unit )
+    {
+    case SizeUnit::Percent:
+        return ( m_value > other.m_value );
+    case SizeUnit::Byte:
+    case SizeUnit::KiB:
+    case SizeUnit::MiB:
+    case SizeUnit::GiB:
+        return ( toBytes() > other.toBytes () );
+    }
+
+    return false;
+}
+
+bool
+PartSize::operator== ( const PartSize& other ) const
+{
+    if ( ( m_unit == SizeUnit::None || other.m_unit == SizeUnit::None ) ||
+         ( m_unit == SizeUnit::Percent && other.m_unit != SizeUnit::Percent ) ||
+         ( m_unit != SizeUnit::Percent && other.m_unit == SizeUnit::Percent ) )
+        return false;
+
+    switch ( m_unit )
+    {
+    case SizeUnit::Percent:
+        return ( m_value == other.m_value );
+    case SizeUnit::Byte:
+    case SizeUnit::KiB:
+    case SizeUnit::MiB:
+    case SizeUnit::GiB:
+        return ( toBytes() == other.toBytes () );
+    }
+
+    return false;
+}
+
+QString
+convenienceName( const Partition* const candidate )
+{
+    if ( !candidate->mountPoint().isEmpty() )
+        return candidate->mountPoint();
+    if ( !candidate->partitionPath().isEmpty() )
+        return candidate->partitionPath();
+    if ( !candidate->devicePath().isEmpty() )
+        return candidate->devicePath();
+    if ( !candidate->deviceNode().isEmpty() )
+        return candidate->devicePath();
+
+    QString p;
+    QTextStream s( &p );
+    s << (void *)candidate;
+
+    return p;
+}
+
 bool
 canBeReplaced( Partition* candidate )
 {
@@ -63,12 +293,12 @@ canBeReplaced( Partition* candidate )
              << QString( "(%1GB)" ).arg( requiredStorageB / 1024 / 1024 / 1024 );
     cDebug() << "Storage capacity  B:" << availableStorageB
              << QString( "(%1GB)" ).arg( availableStorageB / 1024 / 1024 / 1024 )
-             << "for" << candidate->partitionPath() << "   length:" << candidate->length();
+             << "for" << convenienceName( candidate ) << "   length:" << candidate->length();
 
     if ( ok &&
          availableStorageB > requiredStorageB )
     {
-        cDebug() << "Partition" << candidate->partitionPath() << "authorized for replace install.";
+        cDebug() << "Partition" << convenienceName( candidate ) << "authorized for replace install.";
 
         return true;
     }
@@ -85,24 +315,24 @@ canBeResized( Partition* candidate )
         return false;
     }
 
-    cDebug() << "Checking if" << candidate->partitionPath() << "can be resized.";
+    cDebug() << "Checking if" << convenienceName( candidate ) << "can be resized.";
     if ( !candidate->fileSystem().supportGrow() ||
          !candidate->fileSystem().supportShrink() )
     {
-        cDebug() << "  .. filesystem" << candidate->fileSystem().name()
+        cDebug() << Logger::SubEntry << "NO, filesystem" << candidate->fileSystem().name()
             << "does not support resize.";
         return false;
     }
 
     if ( KPMHelpers::isPartitionFreeSpace( candidate ) )
     {
-        cDebug() << "  .. partition is free space";
+        cDebug() << Logger::SubEntry << "NO, partition is free space";
         return false;
     }
 
     if ( candidate->isMounted() )
     {
-        cDebug() << "  .. partition is mounted";
+        cDebug() << Logger::SubEntry << "NO, partition is mounted";
         return false;
     }
 
@@ -111,13 +341,13 @@ canBeResized( Partition* candidate )
         PartitionTable* table = dynamic_cast< PartitionTable* >( candidate->parent() );
         if ( !table )
         {
-            cDebug() << "  .. no partition table found";
+            cDebug() << Logger::SubEntry << "NO, no partition table found";
             return false;
         }
 
         if ( table->numPrimaries() >= table->maxPrimaries() )
         {
-            cDebug() << "  .. partition table already has" 
+            cDebug() << Logger::SubEntry << "NO, partition table already has"
                 << table->maxPrimaries() << "primary partitions.";
             return false;
         }
@@ -128,35 +358,42 @@ canBeResized( Partition* candidate )
                                     ->globalStorage()
                                     ->value( "requiredStorageGB" )
                                     .toDouble( &ok );
+    // We require a little more for partitioning overhead and swap file
     double advisedStorageGB = requiredStorageGB + 0.5 + 2.0;
-
     qint64 availableStorageB = candidate->available();
 
-    // We require a little more for partitioning overhead and swap file
-    // TODO: maybe make this configurable?
-    qint64 advisedStorageB = advisedStorageGB * 1024 * 1024 * 1024;
-    cDebug() << "Required  storage B:" << advisedStorageB
-             << QString( "(%1GB)" ).arg( advisedStorageGB );
-    cDebug() << "Available storage B:" << availableStorageB
-             << QString( "(%1GB)" ).arg( availableStorageB / 1024 / 1024 / 1024 )
-             << "for" << candidate->partitionPath() << "   length:" << candidate->length()
-             << "   sectorsUsed:" << candidate->sectorsUsed() << "   fsType:" << candidate->fileSystem().name();
+    qint64 advisedStorageB = CalamaresUtils::GiBtoBytes( advisedStorageGB );
 
     if ( ok &&
          availableStorageB > advisedStorageB )
     {
-        cDebug() << "Partition" << candidate->partitionPath() << "authorized for resize + autopartition install.";
+        cDebug() << "Partition" << convenienceName( candidate ) << "authorized for resize + autopartition install.";
 
         return true;
     }
-    return false;
+    else if ( ok )
+    {
+        Logger::CDebug deb;
+        deb << Logger::SubEntry << "NO, insufficient storage";
+        deb << Logger::Continuation << "Required  storage B:" << advisedStorageB
+                << QString( "(%1GB)" ).arg( advisedStorageGB );
+        deb << Logger::Continuation << "Available storage B:" << availableStorageB
+                << QString( "(%1GB)" ).arg( availableStorageB / 1024 / 1024 / 1024 )
+                << "for" << convenienceName( candidate ) << "length:" << candidate->length()
+                << "sectorsUsed:" << candidate->sectorsUsed() << "fsType:" << candidate->fileSystem().name();
+        return false;
+    }
+    else
+    {
+        cDebug() << Logger::SubEntry << "NO, requiredStorageGB is not set correctly.";
+        return false;
+    }
 }
 
 
 bool
 canBeResized( PartitionCoreModule* core, const QString& partitionPath )
 {
-    //FIXME: check for max partitions count on DOS MBR
     cDebug() << "Checking if" << partitionPath << "can be resized.";
     QString partitionWithOs = partitionPath;
     if ( partitionWithOs.startsWith( "/dev/" ) )
@@ -168,14 +405,13 @@ canBeResized( PartitionCoreModule* core, const QString& partitionPath )
             Partition* candidate = KPMHelpers::findPartitionByPath( { dev }, partitionWithOs );
             if ( candidate )
             {
-                cDebug() << "  .. found Partition* for" << partitionWithOs;
                 return canBeResized( candidate );
             }
         }
-        cDebug() << "  .. no Partition* found for" << partitionWithOs;
+        cDebug() << Logger::SubEntry << "no Partition* found for" << partitionWithOs;
     }
 
-    cDebug() << "Partition" << partitionWithOs << "CANNOT BE RESIZED FOR AUTOINSTALL.";
+    cDebug() << Logger::SubEntry << "Partition" << partitionWithOs << "CANNOT BE RESIZED FOR AUTOINSTALL.";
     return false;
 }
 
@@ -198,7 +434,7 @@ lookForFstabEntries( const QString& partitionPath )
             mountOptions.append( "noload" );
     }
 
-    cDebug() << "Checking device" << partitionPath 
+    cDebug() << "Checking device" << partitionPath
         << "for fstab (fs=" << r.getOutput() << ')';
 
     FstabEntryList fstabEntries;
@@ -209,9 +445,9 @@ lookForFstabEntries( const QString& partitionPath )
     if ( !exit ) // if all is well
     {
         QFile fstabFile( mountsDir.path() + "/etc/fstab" );
-        
-        cDebug() << "  .. reading" << fstabFile.fileName();
-        
+
+        cDebug() << Logger::SubEntry << "reading" << fstabFile.fileName();
+
         if ( fstabFile.open( QIODevice::ReadOnly | QIODevice::Text ) )
         {
             const QStringList fstabLines = QString::fromLocal8Bit( fstabFile.readAll() )
@@ -220,9 +456,9 @@ lookForFstabEntries( const QString& partitionPath )
             for ( const QString& rawLine : fstabLines )
                 fstabEntries.append( FstabEntry::fromEtcFstab( rawLine ) );
             fstabFile.close();
-            cDebug() << "  .. got" << fstabEntries.count() << "lines.";
+            cDebug() << Logger::SubEntry << "got" << fstabEntries.count() << "lines.";
             std::remove_if( fstabEntries.begin(), fstabEntries.end(), [](const FstabEntry& x) { return !x.isValid(); } );
-            cDebug() << "  .. got" << fstabEntries.count() << "fstab entries.";
+            cDebug() << Logger::SubEntry << "got" << fstabEntries.count() << "fstab entries.";
         }
         else
             cWarning() << "Could not read fstab from mounted fs";
@@ -381,13 +617,13 @@ isEfiSystem()
 bool
 isEfiBootable( const Partition* candidate )
 {
-    cDebug() << "Check EFI bootable" << candidate->partitionPath() << candidate->devicePath();
-    cDebug() << " .. flags" << candidate->activeFlags();
+    cDebug() << "Check EFI bootable" << convenienceName( candidate ) << candidate->devicePath();
+    cDebug() << Logger::SubEntry << "flags" << candidate->activeFlags();
 
     auto flags = PartitionInfo::flags( candidate );
 
     /* If bit 17 is set, old-style Esp flag, it's OK */
-    if ( flags.testFlag( PartitionTable::FlagEsp ) )
+    if ( flags.testFlag( KPM_PARTITION_FLAG_ESP ) )
         return true;
 
     /* Otherwise, if it's a GPT table, Boot (bit 0) is the same as Esp */
@@ -395,7 +631,7 @@ isEfiBootable( const Partition* candidate )
     while ( root && !root->isRoot() )
     {
         root = root->parent();
-        cDebug() << " .. moved towards root" << (void *)root;
+        cDebug() << Logger::SubEntry << "moved towards root" << (void *)root;
     }
 
     // Strange case: no root found, no partition table node?
@@ -403,9 +639,59 @@ isEfiBootable( const Partition* candidate )
         return false;
 
     const PartitionTable* table = dynamic_cast<const PartitionTable*>( root );
-    cDebug() << "  .. partition table" << (void *)table << "type" << ( table ? table->type() : PartitionTable::TableType::unknownTableType );
+    cDebug() << Logger::SubEntry << "partition table" << (void *)table << "type" << ( table ? table->type() : PartitionTable::TableType::unknownTableType );
     return table && ( table->type() == PartitionTable::TableType::gpt ) &&
-        flags.testFlag( PartitionTable::FlagBoot );
+        flags.testFlag( KPM_PARTITION_FLAG(Boot) );
+}
+
+QString
+findFS( QString fsName, FileSystem::Type* fsType )
+{
+    QStringList fsLanguage { QLatin1Literal( "C" ) };  // Required language list to turn off localization
+    if ( fsName.isEmpty() )
+        fsName = QStringLiteral( "ext4" );
+
+    FileSystem::Type tmpType = FileSystem::typeForName( fsName, fsLanguage );
+    if ( tmpType != FileSystem::Unknown )
+    {
+        cDebug() << "Found filesystem" << fsName;
+        if ( fsType )
+            *fsType = tmpType;
+        return fsName;
+    }
+
+    // Second pass: try case-insensitive
+    const auto fstypes = FileSystem::types();
+    for ( FileSystem::Type t : fstypes )
+    {
+        if ( 0 == QString::compare( fsName, FileSystem::nameForType( t, fsLanguage ), Qt::CaseInsensitive ) )
+        {
+            QString fsRealName = FileSystem::nameForType( t, fsLanguage );
+            cDebug() << "Filesystem name" << fsName << "translated to" << fsRealName;
+            if ( fsType )
+                *fsType = t;
+            return fsRealName;
+        }
+    }
+
+    cDebug() << "Filesystem" << fsName << "not found, using ext4";
+    fsName = QStringLiteral( "ext4" );
+    // fsType can be used to check whether fsName was a valid filesystem.
+    if (fsType)
+        *fsType = FileSystem::Unknown;
+#ifdef DEBUG_FILESYSTEMS
+    // This bit is for distro's debugging their settings, and shows
+    // all the strings that KPMCore is matching against for FS type.
+    {
+        Logger::CDebug d;
+        using TR = Logger::DebugRow< int, QString >;
+        const auto fstypes = FileSystem::types();
+        d << "Available types (" << fstypes.count() << ')';
+        for ( FileSystem::Type t : fstypes )
+            d << TR( static_cast<int>( t ), FileSystem::nameForType( t, fsLanguage ) );
+    }
+#endif
+    return fsName;
 }
 
 }  // nmamespace PartUtils
