@@ -2,7 +2,8 @@
  *
  *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
  *   Copyright 2014-2017, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2018, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2018-2019, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2019, Collabora Ltd <arnaud.ferraris@collabora.com>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,6 +22,7 @@
 #include "gui/PartitionViewStep.h"
 
 #include "core/DeviceModel.h"
+#include "core/PartitionActions.h"
 #include "core/PartitionCoreModule.h"
 #include "core/PartitionModel.h"
 #include "core/KPMHelpers.h"
@@ -34,6 +36,7 @@
 #include "CalamaresVersion.h"
 #include "utils/CalamaresUtilsGui.h"
 #include "utils/Logger.h"
+#include "utils/NamedEnum.h"
 #include "utils/Retranslator.h"
 #include "widgets/WaitingWidget.h"
 #include "GlobalStorage.h"
@@ -87,15 +90,16 @@ void
 PartitionViewStep::continueLoading()
 {
     Q_ASSERT( !m_choicePage );
-    Q_ASSERT( !m_manualPartitionPage );
-
-    m_manualPartitionPage = new PartitionPage( m_core );
-    m_choicePage = new ChoicePage();
-
+    m_choicePage = new ChoicePage( m_swapChoices );
     m_choicePage->init( m_core );
-
     m_widget->addWidget( m_choicePage );
-    m_widget->addWidget( m_manualPartitionPage );
+
+    // Instantiate the manual partitioning page as needed.
+    //
+    Q_ASSERT( !m_manualPartitionPage );
+    // m_manualPartitionPage = new PartitionPage( m_core );
+    // m_widget->addWidget( m_manualPartitionPage );
+
     m_widget->removeWidget( m_waitingWidget );
     m_waitingWidget->deleteLater();
     m_waitingWidget = nullptr;
@@ -138,7 +142,7 @@ PartitionViewStep::createSummaryWidget() const
     widget->setLayout( mainLayout );
     mainLayout->setMargin( 0 );
 
-    ChoicePage::Choice choice = m_choicePage->currentChoice();
+    ChoicePage::InstallChoice choice = m_choicePage->currentChoice();
 
     QFormLayout* formLayout = new QFormLayout( widget );
     const int MARGIN = CalamaresUtils::defaultFontHeight() / 2;
@@ -210,8 +214,8 @@ PartitionViewStep::createSummaryWidget() const
         else // multiple disk previews!
         {
             diskInfoLabel->setText( tr( "Disk <strong>%1</strong> (%2)" )
-                                        .arg( info.deviceNode )
-                                        .arg( info.deviceName ) );
+                                    .arg( info.deviceNode )
+                                    .arg( info.deviceName ) );
         }
         formLayout->addRow( diskInfoLabel );
 
@@ -220,9 +224,9 @@ PartitionViewStep::createSummaryWidget() const
         QVBoxLayout* field;
 
         PartitionBarsView::NestedPartitionsMode mode = Calamares::JobQueue::instance()->globalStorage()->
-                                                       value( "drawNestedPartitions" ).toBool() ?
-                                                           PartitionBarsView::DrawNestedPartitions :
-                                                           PartitionBarsView::NoNestedPartitions;
+                value( "drawNestedPartitions" ).toBool() ?
+                PartitionBarsView::DrawNestedPartitions :
+                PartitionBarsView::NoNestedPartitions;
         preview = new PartitionBarsView;
         preview->setNestedPartitionsMode( mode );
         previewLabels = new PartitionLabelsView;
@@ -260,7 +264,7 @@ PartitionViewStep::createSummaryWidget() const
     foreach ( const Calamares::job_ptr& job, jobs() )
     {
         if ( !job->prettyDescription().isEmpty() )
-        jobsLines.append( job->prettyDescription() );
+            jobsLines.append( job->prettyDescription() );
     }
     if ( !jobsLines.isEmpty() )
     {
@@ -284,29 +288,19 @@ PartitionViewStep::next()
     {
         if ( m_choicePage->currentChoice() == ChoicePage::Manual )
         {
+            if ( !m_manualPartitionPage )
+            {
+                m_manualPartitionPage = new PartitionPage( m_core );
+                m_widget->addWidget( m_manualPartitionPage );
+            }
+
             m_widget->setCurrentWidget( m_manualPartitionPage );
+            m_manualPartitionPage->selectDeviceByIndex( m_choicePage->lastSelectedDeviceIndex() );
             if ( m_core->isDirty() )
                 m_manualPartitionPage->onRevertClicked();
         }
-        else if ( m_choicePage->currentChoice() == ChoicePage::Erase )
-        {
-            emit done();
-            return;
-        }
-        else if ( m_choicePage->currentChoice() == ChoicePage::Alongside )
-        {
-            emit done();
-            return;
-        }
-        else if ( m_choicePage->currentChoice() == ChoicePage::Replace )
-        {
-            emit done();
-            return;
-        }
         cDebug() << "Choice applied: " << m_choicePage->currentChoice();
-        return;
     }
-    emit done();
 }
 
 
@@ -314,17 +308,26 @@ void
 PartitionViewStep::back()
 {
     if ( m_widget->currentWidget() != m_choicePage )
+    {
         m_widget->setCurrentWidget( m_choicePage );
+        m_choicePage->setLastSelectedDeviceIndex( m_manualPartitionPage->selectedDeviceIndex() );
+
+        if ( m_manualPartitionPage )
+        {
+            m_manualPartitionPage->deleteLater();
+            m_manualPartitionPage = nullptr;
+        }
+    }
 }
 
 
 bool
 PartitionViewStep::isNextEnabled() const
 {
-    if ( m_choicePage && m_choicePage == m_widget->currentWidget() )
+    if ( m_choicePage && m_widget->currentWidget() == m_choicePage )
         return m_choicePage->isNextEnabled();
 
-    if ( m_manualPartitionPage && m_manualPartitionPage == m_widget->currentWidget() )
+    if ( m_manualPartitionPage && m_widget->currentWidget() == m_manualPartitionPage )
         return m_core->hasRootMountPoint();
 
     return false;
@@ -341,7 +344,7 @@ PartitionViewStep::isBackEnabled() const
 bool
 PartitionViewStep::isAtBeginning() const
 {
-    if ( m_widget->currentWidget() == m_manualPartitionPage )
+    if ( m_widget->currentWidget() != m_choicePage )
         return false;
     return true;
 }
@@ -350,11 +353,11 @@ PartitionViewStep::isAtBeginning() const
 bool
 PartitionViewStep::isAtEnd() const
 {
-    if ( m_choicePage == m_widget->currentWidget() )
+    if ( m_widget->currentWidget() == m_choicePage )
     {
         if ( m_choicePage->currentChoice() == ChoicePage::Erase ||
-             m_choicePage->currentChoice() == ChoicePage::Replace ||
-             m_choicePage->currentChoice() == ChoicePage::Alongside )
+                m_choicePage->currentChoice() == ChoicePage::Replace ||
+                m_choicePage->currentChoice() == ChoicePage::Alongside )
             return true;
         return false;
     }
@@ -367,7 +370,7 @@ PartitionViewStep::onActivate()
 {
     // if we're coming back to PVS from the next VS
     if ( m_widget->currentWidget() == m_choicePage &&
-         m_choicePage->currentChoice() == ChoicePage::Alongside )
+            m_choicePage->currentChoice() == ChoicePage::Alongside )
     {
         m_choicePage->applyActionChoice( ChoicePage::Alongside );
 //        m_choicePage->reset();
@@ -390,7 +393,7 @@ PartitionViewStep::onLeave()
         if ( PartUtils::isEfiSystem() )
         {
             QString espMountPoint = Calamares::JobQueue::instance()->globalStorage()->
-                                        value( "efiSystemPartition").toString();
+                                    value( "efiSystemPartition" ).toString();
             Partition* esp = m_core->findPartitionByMountPoint( espMountPoint );
 
             QString message;
@@ -445,7 +448,7 @@ PartitionViewStep::onLeave()
             // If the root partition is encrypted, and there's a separate boot
             // partition which is not encrypted
             if ( root_p->fileSystem().type() == FileSystem::Luks &&
-                 boot_p->fileSystem().type() != FileSystem::Luks )
+                    boot_p->fileSystem().type() != FileSystem::Luks )
             {
                 message = tr( "Boot partition not encrypted" );
                 description = tr( "A separate boot partition was set up together with "
@@ -476,102 +479,140 @@ PartitionViewStep::setConfigurationMap( const QVariantMap& configurationMap )
     // Copy the efiSystemPartition setting to the global storage. It is needed not only in
     // the EraseDiskPage, but also in the bootloader configuration modules (grub, bootloader).
     Calamares::GlobalStorage* gs = Calamares::JobQueue::instance()->globalStorage();
-    if ( configurationMap.contains( "efiSystemPartition" ) &&
-         configurationMap.value( "efiSystemPartition" ).type() == QVariant::String &&
-         !configurationMap.value( "efiSystemPartition" ).toString().isEmpty() )
+    QString efiSP = CalamaresUtils::getString( configurationMap, "efiSystemPartition" );
+    if ( efiSP.isEmpty() )
+        efiSP = QStringLiteral( "/boot/efi" );
+    gs->insert( "efiSystemPartition", efiSP );
+
+    // Set up firmwareType global storage entry. This is used, e.g. by the bootloader module.
+    QString firmwareType( PartUtils::isEfiSystem() ? QStringLiteral( "efi" ) : QStringLiteral( "bios" ) );
+    cDebug() << "Setting firmwareType to" << firmwareType;
+    gs->insert( "firmwareType", firmwareType );
+
+    // Read and parse key efiSystemPartitionSize
+    if ( configurationMap.contains( "efiSystemPartitionSize" ) )
     {
-        gs->insert( "efiSystemPartition", configurationMap.value( "efiSystemPartition" ).toString() );
-    }
-    else
-    {
-        gs->insert( "efiSystemPartition", QStringLiteral( "/boot/efi" ) );
+        gs->insert( "efiSystemPartitionSize", CalamaresUtils::getString( configurationMap, "efiSystemPartitionSize" ) );
     }
 
-    if ( configurationMap.contains( "ensureSuspendToDisk" ) &&
-         configurationMap.value( "ensureSuspendToDisk" ).type() == QVariant::Bool )
-    {
-        gs->insert( "ensureSuspendToDisk", configurationMap.value( "ensureSuspendToDisk" ).toBool() );
-    }
-    else
-    {
-        gs->insert( "ensureSuspendToDisk", true );
-    }
+    // SWAP SETTINGS
+    //
+    // This is a bit convoluted because there's legacy settings to handle as well
+    // as the new-style list of choices, with mapping back-and-forth.
+    if ( configurationMap.contains( "userSwapChoices" ) &&
+        ( configurationMap.contains( "ensureSuspendToDisk" ) || configurationMap.contains( "neverCreateSwap" ) ) )
+        cError() << "Partition-module configuration mixes old- and new-style swap settings.";
 
-    if ( configurationMap.contains( "neverCreateSwap" ) &&
-         configurationMap.value( "neverCreateSwap" ).type() == QVariant::Bool )
-    {
-        gs->insert( "neverCreateSwap", configurationMap.value( "neverCreateSwap" ).toBool() );
-    }
-    else
-    {
-        gs->insert( "neverCreateSwap", false );
-    }
+    if ( configurationMap.contains( "ensureSuspendToDisk" ) )
+        cWarning() << "Partition-module setting *ensureSuspendToDisk* is deprecated.";
+    bool ensureSuspendToDisk = CalamaresUtils::getBool( configurationMap, "ensureSuspendToDisk", true );
 
-    if ( configurationMap.contains( "drawNestedPartitions" ) &&
-         configurationMap.value( "drawNestedPartitions" ).type() == QVariant::Bool )
-    {
-        gs->insert( "drawNestedPartitions",
-                    configurationMap.value( "drawNestedPartitions", false ).toBool() );
-    }
-    else
-    {
-        gs->insert( "drawNestedPartitions", false );
-    }
+    if ( configurationMap.contains( "neverCreateSwap" ) )
+        cWarning() << "Partition-module setting *neverCreateSwap* is deprecated.";
+    bool neverCreateSwap = CalamaresUtils::getBool( configurationMap, "neverCreateSwap", false );
 
-    if ( configurationMap.contains( "alwaysShowPartitionLabels" ) &&
-         configurationMap.value( "alwaysShowPartitionLabels" ).type() == QVariant::Bool )
+    QSet< PartitionActions::Choices::SwapChoice > choices;  // Available swap choices
+    if ( configurationMap.contains( "userSwapChoices" ) )
     {
-        gs->insert( "alwaysShowPartitionLabels",
-                    configurationMap.value( "alwaysShowPartitionLabels", true ).toBool() );
-    }
-    else
-    {
-        gs->insert( "alwaysShowPartitionLabels", true );
-    }
+        // We've already warned about overlapping settings with the
+        // legacy *ensureSuspendToDisk* and *neverCreateSwap*.
+        QStringList l = configurationMap[ "userSwapChoices" ].toStringList();
 
-    if ( configurationMap.contains( "defaultFileSystemType" ) &&
-         configurationMap.value( "defaultFileSystemType" ).type() == QVariant::String &&
-         !configurationMap.value( "defaultFileSystemType" ).toString().isEmpty() )
-    {
-        QString typeString = configurationMap.value( "defaultFileSystemType" ).toString();
-        gs->insert( "defaultFileSystemType", typeString );
-        if ( FileSystem::typeForName( typeString ) == FileSystem::Unknown )
+        for ( const auto& item : l )
         {
-            cWarning() << "bad default filesystem configuration for partition module. Reverting to ext4 as default.";
-            gs->insert( "defaultFileSystemType", "ext4" );
+            bool ok = false;
+            auto v = PartitionActions::Choices::nameToChoice( item, ok );
+            if ( ok )
+                choices.insert( v );
         }
+
+        if ( choices.isEmpty() )
+        {
+            cWarning() << "Partition-module configuration for *userSwapChoices* is empty:" << l;
+            choices.insert( PartitionActions::Choices::SwapChoice::FullSwap );
+        }
+
+        // suspend if it's one of the possible choices; suppress swap only if it's
+        // the **only** choice available.
+        ensureSuspendToDisk = choices.contains( PartitionActions::Choices::SwapChoice::FullSwap );
+        neverCreateSwap = ( choices.count() == 1 ) && choices.contains( PartitionActions::Choices::SwapChoice::NoSwap );
     }
     else
     {
-        gs->insert( "defaultFileSystemType", QStringLiteral( "ext4" ) );
+        // Convert the legacy settings into a single setting for now.
+        if ( neverCreateSwap )
+            choices.insert( PartitionActions::Choices::SwapChoice::NoSwap );
+        else if ( ensureSuspendToDisk )
+            choices.insert( PartitionActions::Choices::SwapChoice::FullSwap );
+        else
+            choices.insert( PartitionActions::Choices::SwapChoice::SmallSwap );
     }
 
-    if ( configurationMap.contains( "enableLuksAutomatedPartitioning" ) &&
-         configurationMap.value( "enableLuksAutomatedPartitioning" ).type() == QVariant::Bool )
-    {
-        gs->insert( "enableLuksAutomatedPartitioning",
-                    configurationMap.value( "enableLuksAutomatedPartitioning" ).toBool() );
-    }
+    // Not all are supported right now // FIXME
+    static const char unsupportedSetting[] = "Partition-module does not support *userSwapChoices* setting";
+
+#define COMPLAIN_UNSUPPORTED(x) \
+    if ( choices.contains( x ) ) \
+    { cWarning() << unsupportedSetting << PartitionActions::Choices::choiceToName( x ); choices.remove( x ); }
+
+    COMPLAIN_UNSUPPORTED( PartitionActions::Choices::SwapChoice::SwapFile )
+    COMPLAIN_UNSUPPORTED( PartitionActions::Choices::SwapChoice::ReuseSwap )
+#undef COMPLAIN_UNSUPPORTED
+
+    m_swapChoices = choices;
+
+    // These gs settings seem to be unused (in upstream Calamares) outside of
+    // the partition module itself.
+    gs->insert( "ensureSuspendToDisk", ensureSuspendToDisk );
+    gs->insert( "neverCreateSwap", neverCreateSwap );
+
+    // OTHER SETTINGS
+    //
+    gs->insert( "drawNestedPartitions", CalamaresUtils::getBool( configurationMap, "drawNestedPartitions", false ) );
+    gs->insert( "alwaysShowPartitionLabels", CalamaresUtils::getBool( configurationMap, "alwaysShowPartitionLabels", true ) );
+    gs->insert( "enableLuksAutomatedPartitioning", CalamaresUtils::getBool( configurationMap, "enableLuksAutomatedPartitioning", true ) );
+    gs->insert( "allowManualPartitioning", CalamaresUtils::getBool( configurationMap, "allowManualPartitioning", true ) );
+
+    // The defaultFileSystemType setting needs a bit more processing,
+    // as we want to cover various cases (such as different cases)
+    QString fsName = CalamaresUtils::getString( configurationMap, "defaultFileSystemType" );
+    FileSystem::Type fsType;
+    if ( fsName.isEmpty() )
+            cWarning() << "Partition-module setting *defaultFileSystemType* is missing, will use ext4";
+    QString fsRealName = PartUtils::findFS( fsName, &fsType );
+    if ( fsRealName == fsName )
+        cDebug() << "Partition-module setting *defaultFileSystemType*" << fsRealName;
+    else if ( fsType != FileSystem::Unknown )
+        cWarning() << "Partition-module setting *defaultFileSystemType* changed" << fsRealName;
     else
-    {
-        gs->insert( "enableLuksAutomatedPartitioning", true );
-    }
+        cWarning() << "Partition-module setting *defaultFileSystemType* is bad (" << fsRealName << ") using ext4.";
+    gs->insert( "defaultFileSystemType", fsRealName );
 
 
     // Now that we have the config, we load the PartitionCoreModule in the background
     // because it could take a while. Then when it's done, we can set up the widgets
     // and remove the spinner.
-    QFutureWatcher< void >* watcher = new QFutureWatcher< void >();
-    connect( watcher, &QFutureWatcher< void >::finished,
-             this, [ this, watcher ]
+    m_future = new QFutureWatcher< void >();
+    connect( m_future, &QFutureWatcher< void >::finished,
+             this, [ this ]
     {
         continueLoading();
-        watcher->deleteLater();
+        this->m_future->deleteLater();
+        this->m_future = nullptr;
     } );
 
     QFuture< void > future =
-            QtConcurrent::run( this, &PartitionViewStep::initPartitionCoreModule );
-    watcher->setFuture( future );
+        QtConcurrent::run( this, &PartitionViewStep::initPartitionCoreModule );
+    m_future->setFuture( future );
+
+    if ( configurationMap.contains( "partitionLayout" ) )
+    {
+        m_core->initLayout( configurationMap.values( "partitionLayout" ).at(0).toList() );
+    }
+    else
+    {
+        m_core->initLayout();
+    }
 }
 
 
@@ -581,5 +622,24 @@ PartitionViewStep::jobs() const
     return m_core->jobs();
 }
 
+Calamares::RequirementsList
+PartitionViewStep::checkRequirements()
+{
+    if ( m_future )
+        m_future->waitForFinished();
+
+    Calamares::RequirementsList l;
+    l.append(
+    {
+        QLatin1Literal( "partitions" ),
+        []{ return tr( "has at least one disk device available." ); },
+        []{ return tr( "There are no partitons to install on." ); },
+        m_core->deviceModel()->rowCount() > 0,  // satisfied
+        true    // required
+    } );
+
+    return l;
+}
+
 
 CALAMARES_PLUGIN_FACTORY_DEFINITION( PartitionViewStepFactory, registerPlugin<PartitionViewStep>(); )
