@@ -21,13 +21,13 @@
  * shipped with each module for correctness -- well, for parseability.
  */
 
+#include "utils/YamlUtils.h"
+
 #include <unistd.h>
 #include <stdlib.h>
 
 #include <iostream>
 
-#include <yaml-cpp/yaml.h>
-
 #include <QFile>
 #include <QByteArray>
 
